@@ -20,7 +20,8 @@
  * USA
  */
 
-#include <config.h>
+#include "config.h"
+
 #include <glib/gi18n.h>
 
 #include "screenshot-config.h"
